define(
//begin v1.x content
({
	insertTableTitle: "Вставить таблицу",
	modifyTableTitle: "Изменить таблицу",
	rows: "Строк:",
	columns: "Столбцов:",
	align: "Выровнять:",
	cellPadding: "Отступ внутри ячеек:",
	cellSpacing: "Расстояние между ячейками:",
	tableWidth: "Ширина таблицы:",
	backgroundColor: "Цвет фона:",
	borderColor: "Цвет рамки:",
	borderThickness: "Толщина рамки",
	percent: "процентов",
	pixels: "пикселов",
	"default": "по умолчанию",
	left: "по левому краю",
	center: "по центру",
	right: "по правому краю",
	buttonSet: "Задать", // translated elsewhere?
	buttonInsert: "Вставить",
	buttonCancel: "Отмена",

	selectTableLabel: "Выбрать таблицу",
	insertTableRowBeforeLabel: "Добавить строку перед",
	insertTableRowAfterLabel: "Добавить строку после",
	insertTableColumnBeforeLabel: "Добавить столбец перед",
	insertTableColumnAfterLabel: "Добавить столбец после",
	deleteTableRowLabel: "Удалить строку",
	deleteTableColumnLabel: "Удалить столбец"
})
//end v1.x content
);
